@@ -2,7 +2,7 @@
    +----------------------------------------------------------------------+
    | Zend Engine                                                          |
    +----------------------------------------------------------------------+
-   | Copyright (c) 1998-2018 Zend Technologies Ltd. (http://www.zend.com) |
+   | Copyright (c) Zend Technologies Ltd. (http://www.zend.com)           |
    +----------------------------------------------------------------------+
    | This source file is subject to version 2.00 of the Zend license,     |
    | that is bundled with this package in the file LICENSE, and is        |
@@ -17,8 +17,6 @@
    +----------------------------------------------------------------------+
 */
 
-/* $Id$ */
-
 #ifndef ZEND_MULTIBYTE_H
 #define ZEND_MULTIBYTE_H
 
@@ -28,12 +26,12 @@ typedef size_t (*zend_encoding_filter)(unsigned char **str, size_t *str_length,
 
 typedef const zend_encoding* (*zend_encoding_fetcher)(const char *encoding_name);
 typedef const char* (*zend_encoding_name_getter)(const zend_encoding *encoding);
-typedef int (*zend_encoding_lexer_compatibility_checker)(const zend_encoding *encoding);
+typedef bool (*zend_encoding_lexer_compatibility_checker)(const zend_encoding *encoding);
 typedef const zend_encoding *(*zend_encoding_detector)(const unsigned char *string, size_t length, const zend_encoding **list, size_t list_size);
 typedef size_t (*zend_encoding_converter)(unsigned char **to, size_t *to_length, const unsigned char *from, size_t from_length, const zend_encoding *encoding_to, const zend_encoding *encoding_from);
-typedef int (*zend_encoding_list_parser)(const char *encoding_list, size_t encoding_list_len, const zend_encoding ***return_list, size_t *return_size, int persistent);
+typedef zend_result (*zend_encoding_list_parser)(const char *encoding_list, size_t encoding_list_len, const zend_encoding ***return_list, size_t *return_size, bool persistent);
 typedef const zend_encoding *(*zend_encoding_internal_encoding_getter)(void);
-typedef int (*zend_encoding_internal_encoding_setter)(const zend_encoding *encoding);
+typedef zend_result (*zend_encoding_internal_encoding_setter)(const zend_encoding *encoding);
 
 typedef struct _zend_multibyte_functions {
     const char *provider_name;
@@ -59,7 +57,7 @@ ZEND_API extern const zend_encoding *zend_multibyte_encoding_utf16le;
 ZEND_API extern const zend_encoding *zend_multibyte_encoding_utf8;
 
 /* multibyte utility functions */
-ZEND_API int zend_multibyte_set_functions(const zend_multibyte_functions *functions);
+ZEND_API zend_result zend_multibyte_set_functions(const zend_multibyte_functions *functions);
 ZEND_API void zend_multibyte_restore_functions(void);
 ZEND_API const zend_multibyte_functions *zend_multibyte_get_functions(void);
 
@@ -68,23 +66,14 @@ ZEND_API const char *zend_multibyte_get_encoding_name(const zend_encoding *encod
 ZEND_API int zend_multibyte_check_lexer_compatibility(const zend_encoding *encoding);
 ZEND_API const zend_encoding *zend_multibyte_encoding_detector(const unsigned char *string, size_t length, const zend_encoding **list, size_t list_size);
 ZEND_API size_t zend_multibyte_encoding_converter(unsigned char **to, size_t *to_length, const unsigned char *from, size_t from_length, const zend_encoding *encoding_to, const zend_encoding *encoding_from);
-ZEND_API int zend_multibyte_parse_encoding_list(const char *encoding_list, size_t encoding_list_len, const zend_encoding ***return_list, size_t *return_size, int persistent);
+ZEND_API zend_result zend_multibyte_parse_encoding_list(const char *encoding_list, size_t encoding_list_len, const zend_encoding ***return_list, size_t *return_size, bool persistent);
 
 ZEND_API const zend_encoding *zend_multibyte_get_internal_encoding(void);
 ZEND_API const zend_encoding *zend_multibyte_get_script_encoding(void);
 ZEND_API int zend_multibyte_set_script_encoding(const zend_encoding **encoding_list, size_t encoding_list_size);
-ZEND_API int zend_multibyte_set_internal_encoding(const zend_encoding *encoding);
-ZEND_API int zend_multibyte_set_script_encoding_by_string(const char *new_value, size_t new_value_length);
+ZEND_API zend_result zend_multibyte_set_internal_encoding(const zend_encoding *encoding);
+ZEND_API zend_result zend_multibyte_set_script_encoding_by_string(const char *new_value, size_t new_value_length);
 
 END_EXTERN_C()
 
 #endif /* ZEND_MULTIBYTE_H */
-
-/*
- * Local variables:
- * tab-width: 4
- * c-basic-offset: 4
- * End:
- * vim600: sw=4 ts=4 tw=78
- * vim<600: sw=4 ts=4 tw=78
- */
